@@ -12,6 +12,13 @@
 
 /* This is always defined.  It enables GNU extensions on systems that
    have them.  */
-#ifndef _GNU_SOURCE
+#if !defined(_GNU_SOURCE)
 # undef _GNU_SOURCE
 #endif
+
+#if !defined(__USE_BSD)
+# undef __USE_BSD
+#endif
+
+#undef HAVE_NAMESPACES
+#undef HAVE_STL
