@@ -81,7 +81,7 @@ void add_mac_addresses(vpn_packet_t *p)
   tmp[0] = tmp[6] = 0xfe;
   tmp[1] = tmp[7] = 0xfd;
   *((ip_t*)(&tmp[2])) = *((ip_t*)(&tmp[30]));  /* !!  ?? */
-  *((ip_t*)(&tmp[8])) = *((ip_t*)(&tmp[26]));
+  *((ip_t*)(&tmp[8])) = (ip_t)(htonl(myself->vpn_ip));
   memcpy(p->data, &tmp[0], p->len);
 }
 
